@@ -38,6 +38,7 @@
 #define CDRECORD_INAPPROPRIATE "Inappropriate audio coding"
 #define CDRECORD_INPUTOUTPUT_ERROR "Input/output error."
 #define CDRECORD_FIXATING "Fixating..."
+#define CDRECORD_BLANKING "Blanking "
 #define CDRECORD_BAD_RECORDER "Sorry, no CD/DVD-Recorder or unsupported CD/DVD-Recorder found"
 
 /* support du materiel */
@@ -58,7 +59,7 @@
 /* effacer un cdrw ou cloturer un cdr */
 #define CDRECORD_BLANKING_TIME "Blanking time:"
 #define CDRECORD_CANNOT_BLANK "Cannot blank disk, aborting"
-#define CDRECORD_INCOMPATIBLE_MEDIUM "cannot format medium - incompatible medium"
+#define CDRECORD_INCOMPATIBLE_MEDIUM "cannot format medium - incmedium"
 #define CDRECORD_FIXATING_TIME "Fixating time:"
 
 
@@ -627,6 +628,9 @@ _DEB("===>%s", Lbuffer);
   } else if (strstr(Lbuffer, CDRECORD_FIXATING)) {
     /* cloture du cd */
     gtk_label_set_text(Ltitle, _("Fixating..."));
+  } else if (strstr(Lbuffer, CDRECORD_BLANKING)) {
+    /* blanking disk */
+    gtk_label_set_text(Ltitle, _("Blanking..."));
   } else if ((f=strstr(Lbuffer, CDRECORD_STATUS))) {
     gboolean *Lstatus = (gboolean *) g_hash_table_lookup(Lhash, "operationstatus");
 /* bug 11803
@@ -644,7 +648,11 @@ _DEB("===>%s", Lbuffer);
     g_set_error(Lerreur, GRAVEMAN_ERROR, _ERR_NO_CD, _("Error writing CD !"));
     (*Lcont) = 0;
     return FALSE;
-  } else if (strstr(Lbuffer, CDRECORD_ERRORDISK)) {
+  } else if (strstr(Lbuffer, CDRECORD_CANNOT_BLANK)) {
+    g_set_error(Lerreur, GRAVEMAN_ERROR, _ERR_CANNOT_BLANK, _("Cannot blank disk, aborting."));
+    (*Lcont) = 0;
+    return FALSE;
+  } else if ((strstr(Lbuffer, CDRECORD_ERRORDISK)) || (strstr(Lbuffer, CDRECORD_INCOMPATIBLE_MEDIUM))) {
     /* erreur pas de cd vierge */
     g_set_error(Lerreur, GRAVEMAN_ERROR, _ERR_NO_CD, _("Error, a CD-R/CD-RW is required in the cd recorder !"));
     (*Lcont) = 0;
@@ -923,7 +931,6 @@ gboolean perform_erase_cdrw(GHashTable *Ahash, GError **Aerror)
   g_free(Lbufgrav);
 
   _DEB("execution [%s]\n", Lcommandline);
-  printf("execution [%s]\n", Lcommandline);
   Lstatus = g_shell_parse_argv(Lcommandline, &Lnbrarg, &Lcmd, Aerror);
   g_free(Lcommandline);
 
@@ -1039,6 +1046,16 @@ _DEB("fin !!!\n");
 }
 
 
+/* ejecter un CD */
+void eject_cd(gchar *Adev, GError **Aerror)
+{
+  gchar *Lcommandline = g_strdup_printf("%s -eject dev=%s", conf_get_string("cdrecord"), Adev);
+  _DEB("EJECT %s\n", Adev);
+  
+  g_spawn_command_line_sync(Lcommandline, NULL, NULL, NULL, Aerror);
+
+  g_free(Lcommandline);
+}
 
 /*
  * vim:et:ts=8:sts=2:sw=2
