@@ -32,26 +32,64 @@ gint Gfifosize = 6; /* taille fifo en MO */
 /* liste des directives utilisees dans le fichier de configuration
  * TYPE, clef, requis ou non, valeur par defaut */
 TProgRequis Glisteprogrequis[] = {
-  { CONF_PROG, "cdrecord", TRUE, "" },
-  { CONF_STRING, "cdrecordpara", FALSE, "" },
-  { CONF_PROG, "mkisofs", TRUE, "" },
-  { CONF_STRING, "mkisofspara", FALSE, ""},
-  { CONF_PROG, "readcd", TRUE, ""},
-  { CONF_STRING, "readcdpara", FALSE, ""},
-  { CONF_PROG, "sox", TRUE, ""},
-  { CONF_STRING, "soxpara", FALSE, ""},
-  { CONF_PROG, "dvd+rw-mediainfo", TRUE, ""},
-  { CONF_STRING, "dvd+rw-mediainfopara", FALSE, ""},
-  { CONF_PROG, "growisofs", TRUE, ""},
-  { CONF_STRING, "growisofspara", FALSE, ""},
-  { CONF_DIR, "tmpdir", TRUE, "/tmp"},
-  { CONF_STRING, "overburn", FALSE, "1" },
-  { CONF_STRING, "fastblank", FALSE, "1" },
-  { CONF_STRING, "eject", FALSE, "1" },
+  { CONF_PROG, "cdrecord", "", CONF_SAVEALWAYS },
+  { CONF_STRING, "cdrecordpara", "", CONF_SAVEALWAYS },
+  { CONF_PROG, "mkisofs", "", CONF_SAVEALWAYS },
+  { CONF_STRING, "mkisofspara", "", CONF_SAVEALWAYS },
+  { CONF_PROG, "readcd", "", CONF_SAVEALWAYS },
+  { CONF_STRING, "readcdpara", "", CONF_SAVEALWAYS },
+  { CONF_PROG, "sox", "", CONF_SAVEALWAYS },
+  { CONF_STRING, "soxpara", "", CONF_SAVEALWAYS },
+  { CONF_PROG, "dvd+rw-mediainfo", "", CONF_SAVEALWAYS },
+  { CONF_STRING, "dvd+rw-mediainfopara", "", CONF_SAVEALWAYS },
+  { CONF_PROG, "dvd+rw-format", "", CONF_SAVEALWAYS },
+  { CONF_STRING, "dvd+rw-formatpara", "", CONF_SAVEALWAYS },
+  { CONF_PROG, "growisofs", "", CONF_SAVEALWAYS },
+  { CONF_STRING, "growisofspara", "", CONF_SAVEALWAYS },
+  { CONF_DIR, "tmpdir", "/tmp", CONF_SAVEALWAYS },
+  { CONF_STRING, "overburn", "1", CONF_SAVEALWAYS },
+  { CONF_STRING, "autoblank", "1", CONF_SAVEALWAYS },
+  { CONF_STRING, "fastblank", "1", CONF_SAVEALWAYS },
+  { CONF_STRING, "eject", "1", CONF_SAVEALWAYS },
+  { CONF_STRING, "iconsize", "48", CONF_SAVEALWAYS },
+  { CONF_STRING, "statusbar", "1", CONF_SAVEALWAYS },
+  { CONF_STRING, "saveconfig", "1", CONF_SAVEALWAYS },
+
+  /* onglet audio */
+  { CONF_STRING, "dstaudiocombo", "", CONF_SAVEONEXIT + CONF_COMBO },
+  { CONF_STRING, "dstaudiospeed", "", CONF_SAVEONEXIT + CONF_COMBO },
+  { CONF_STRING, "audiodao", "1", CONF_SAVEONEXIT + CONF_CHECK },
+  { CONF_STRING, "audionotfix", "1", CONF_SAVEONEXIT + CONF_CHECK },
+  { CONF_STRING, "audiosimul", "1", CONF_SAVEONEXIT + CONF_CHECK },
+  { CONF_STRING, "nbrcdaudio", "1", CONF_SAVEONEXIT + CONF_SPIN },
+  
+  /* onglet data */
+  { CONF_STRING, "dstdatacombo", "", CONF_SAVEONEXIT + CONF_COMBO },
+  { CONF_STRING, "dstdataspeed", "", CONF_SAVEONEXIT + CONF_COMBO },
+  { CONF_STRING, "nbrcddata", "1", CONF_SAVEONEXIT + CONF_SPIN },
+  { CONF_STRING, "dataformat", "", CONF_SAVEONEXIT + CONF_COMBO },
+  { CONF_STRING, "datamodburn", "", CONF_SAVEONEXIT + CONF_COMBO },
+  { CONF_STRING, "dataisolevel", "", CONF_SAVEONEXIT + CONF_COMBO },
+  { CONF_STRING, "datarockridge", "1", CONF_SAVEONEXIT + CONF_CHECK },
+  { CONF_STRING, "datajoliet", "1", CONF_SAVEONEXIT + CONF_CHECK },
+  { CONF_STRING, "datamulti", "", CONF_SAVEONEXIT + CONF_CHECK },
+  { CONF_STRING, "datanotfix", "", CONF_SAVEONEXIT + CONF_CHECK },
+  { CONF_STRING, "datasimul", "", CONF_SAVEONEXIT + CONF_CHECK },
+
+ /* onglet copier */
+  { CONF_STRING, "srccopycombo", "", CONF_SAVEONEXIT + CONF_COMBO },
+  { CONF_STRING, "dstcopycombo", "", CONF_SAVEONEXIT + CONF_COMBO },
+  { CONF_STRING, "dstcopyspeed", "", CONF_SAVEONEXIT + CONF_COMBO },
+  { CONF_STRING, "nbrcdcopy", "1", CONF_SAVEONEXIT + CONF_SPIN },
+  { CONF_STRING, "copysimul", "1", CONF_SAVEONEXIT + CONF_CHECK },
+
+  /* onglet autres */
+  { CONF_STRING, "dstothercombo", "", CONF_SAVEONEXIT + CONF_COMBO },
+  
 #if 0
   { CONF_STRING, "extended", FALSE, "1" },
 #endif
-  { CONF_IGNORE, NULL, FALSE, NULL },
+  { CONF_IGNORE, NULL, NULL, 0 },
 };
 
 TProgRequis *getentrydef(gchar *Aentry)
@@ -158,6 +196,9 @@ void config_init()
   conf_store_value("fastblank", "1");
   conf_store_value("tmpdir", "/tmp");
   conf_store_value("lastdir", "");
+  conf_store_value("iconsize", "48");
+  conf_store_value("statusbar", "1");
+  conf_store_value("saveconfig", "1");
   if (s) {
     Gfifosize = atoi(s);
     if (Gfifosize<=0) Gfifosize=6;
@@ -166,7 +207,7 @@ void config_init()
 
 /* on regarde si un fichier de configuration existe 
  * dans /usr/share/graveman/graveman.rc ou ~/.graveman/graveman.rc */
-gint is_config_valide()
+gint is_config_valid()
 {
   const gchar *LHome = g_getenv("HOME");
   gchar LUserConf[1024], LGlobalConf[1024];
@@ -208,7 +249,6 @@ gchar *trouveUnProg(gchar *Anomprog)
     if (s) *(s++)=0;
 
     g_snprintf(Ltest, sizeof(Ltest)-1, "%s/%s", p, Anomprog);
-
     if (0==stat(Ltest, &Lficinfo) && S_ISREG(Lficinfo.st_mode)) {
       Lrespath = strdup(Ltest);
       break;
@@ -310,14 +350,46 @@ gboolean config_append_media(gulong Alen, gchar *Alabeldata, gchar *Alabelaudio)
   return TRUE;
 }
 
-/* initialisation d'une nouvelle configuration */
-gint manage_new_config(GHashTable *Ahash, gshort Aop, GError **Aerror)
+/* savegarde de la valeur de certains champs du formulaire lorsque
+ * l'option "save on exit" est active */
+void manage_saveonexit_value(GHashTable *Ahash)
+{
+  TProgRequis *Lcurentry;
+  GtkWidget *Lwidget;
+
+  for (Lcurentry = Glisteprogrequis; Lcurentry->entry; Lcurentry++) {
+    if (!(Lcurentry->level & CONF_SAVEONEXIT)) continue;
+    Lwidget = g_hash_table_lookup(Ahash, Lcurentry->entry);
+
+    if (!GTK_IS_WIDGET(Lwidget)) {
+      g_warning("Error %s is missing!", Lcurentry->entry);
+      continue;
+    }
+    _DEB("on sauve '%s'\n", Lcurentry->entry);
+        
+    if (Lcurentry->level & CONF_COMBO) {
+      conf_store_value(Lcurentry->entry, get_combo_value(Lwidget));
+    } else if (Lcurentry->level & CONF_SPIN) {
+      conf_store_int(Lcurentry->entry, gtk_spin_button_get_value(GTK_SPIN_BUTTON(Lwidget)));
+    } else if (Lcurentry->level & CONF_CHECK) {
+      conf_store_value(Lcurentry->entry, _BOOLEAN_CONF(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(Lwidget))));
+    }
+  }
+}
+
+/* gestion de la configuration (creation/chargement/sauvegarde...) */
+gint manage_config(GHashTable *Ahash, gshort Aop, GError **Aerror)
 {
   TProgRequis *Lcurprog;
   gchar *Lprog;
   GtkWidget *Lwindow1;
   Lwindow1 = g_hash_table_lookup(Ahash, "topwindow");
 
+  if (Aop & UPDATE_SAVEONEXIT_VALUE) {
+    /* mise a jour des valeurs a sauvegarder lorsque l'on quitte */
+    manage_saveonexit_value(Ahash);
+  }
+
   if (Aop & SEARCH_PROG) {
     /* on recherche les programmes externes */
     for (Lcurprog = Glisteprogrequis; Lcurprog->entry; Lcurprog++) {
@@ -561,6 +633,7 @@ void maj_proprietes_prog(GHashTable *Ahash)
   }
 }
 
+/* on restaure la derniere position et taille de la fenetre */
 void restore_main_window_pos(GtkWidget *Awindow1)
 {
   gint Lx = conf_get_int("x");
@@ -574,6 +647,31 @@ void restore_main_window_pos(GtkWidget *Awindow1)
   }
 }
 
+/* on restaure les dernieres valeurs utilisees pour certains champs */
+void restore_last_used_values(GHashTable *Ahash)
+{
+  TProgRequis *Lcurentry;
+  GtkWidget *Lwidget;
+
+  for (Lcurentry = Glisteprogrequis; Lcurentry->entry; Lcurentry++) {
+    if (!(Lcurentry->level & CONF_SAVEONEXIT)) continue;
+
+    if ((Lcurentry->level & CONF_SPIN) || (Lcurentry->level & CONF_CHECK)) {
+      Lwidget = g_hash_table_lookup(Ahash, Lcurentry->entry);
+      if (!GTK_IS_WIDGET(Lwidget)) {
+        g_warning("Error %s is missing!", Lcurentry->entry);
+        continue;
+      }
+
+      if (Lcurentry->level & CONF_SPIN) {
+        gtk_spin_button_set_value(GTK_SPIN_BUTTON(Lwidget), conf_get_int(Lcurentry->entry));
+      } else {
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(Lwidget), conf_get_boolean(Lcurentry->entry));
+      }
+    }
+  }
+}
+
 /* utilisation du dernier repertoire visite */
 void use_last_dir(GtkFileChooser *Awidget)
 {
