@@ -117,6 +117,12 @@ typedef enum {
   CONF_BOOLEAN
 } Ttypeconf;
 
+typedef enum {
+  DVD_FORMAT,
+  DVD_BLANK,
+  DVD_FULLBLANK
+} Ttypeformatdvd;
+
 #ifdef ENABLE_MP3
   #define MP3 ".mp3"
 #endif
@@ -198,6 +204,9 @@ extern gchar *make_audio_fileslist(gint Anbrfiles);
 /* data.c */
 extern gboolean preparedata(GHashTable *Ahash, GError **Aerror);
 
+/* dvdrwformat.c */
+extern gboolean perform_format_dvd(GHashTable *Ahash, Ttypeformatdvd Aoperation, GError **Aerror);
+
 /* images.c */
 extern GdkPixbuf *GDirIcone;
 extern GdkPixbuf *GFileIcone;
@@ -235,6 +244,7 @@ extern GtkMenu *create_gtkpopupmenudata(GtkWidget *Aliste, GHashTable *Ahash);
 extern GtkMenu *create_gtkpopupmenuaudio(GtkWidget *Aliste, GHashTable *Ahash);
 extern GtkMenu *create_gtkpopupmenudevices(GtkWidget *Aliste, GHashTable *Ahash);
 extern GtkMenu *create_gtkpopupmenudisplay(GtkWidget *Aliste, GHashTable *Ahash);
+extern GtkMenu *create_gtkpopupmenuformatdvd(GHashTable *Ahash);
 extern gboolean gtk_do_eventbuttonpress(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
 extern GtkWidget* create_addpisteselection (GtkWindow *AParent);
 extern GladeXML *create_window_encours(GtkWidget *AParent);
@@ -252,7 +262,7 @@ extern void prepare_listedata(GtkTreeView *Atreedata);
 extern void prepare_listeaudio(GtkTreeView *Atreeaudio);
 extern void prepare_popups(GladeXML *Axml, GHashTable *Ahash);
 extern void prepare_disable_when_iso(GHashTable *Ahash, gchar *Abasename, const gchar *Afirst, ...);
-extern void prepare_disable_when_notcdrw(GHashTable *Ahash, gchar *Abasename, const gchar *Afirst, ...);
+extern void prepare_disable_when(GHashTable *Ahash, gchar *Abasename, const gchar *Afirst, ...);
 extern void show_erasecdrwwindow(GHashTable *Ahash);
 extern void show_fixcdwindow(GHashTable *Ahash);
 extern void manage_combobox_devicebus(GtkComboBox *Acombobox, Tdriveinfo *Adrive);
@@ -264,6 +274,7 @@ extern void gtk_toggle_top_menu(GtkTreeView *Atopmenu, gpointer Adata);
 extern GHashTable *create_dialog_confirm_operation (GtkWidget *Aparent, gchar *Alabel, 
                       gchar *Acheckboxlbl, gboolean Acheckboxstatus);
 extern void update_status_bar_display(GHashTable *Ahash);
+extern void show_dvdformatwindow(GHashTable *Ahash, gchar *Atitle, Ttypeformatdvd Aoperation);
 
 /* log.c */
 extern GQuark graveman_error_quark (void);
@@ -276,7 +287,7 @@ extern TProgRequis Glisteprogrequis[];
 extern void config_init();
 extern void clean_config();
 extern gchar *get_config_file_name();
-extern gint is_config_valide();
+extern gint is_config_valid();
 extern gint manage_config(GHashTable *Ahash, gshort Aop, GError **Aerror);
 extern gint Gfifosize;
 extern gchar *conf_get_string(gchar *Anom);
@@ -319,6 +330,7 @@ extern gboolean gravepiste(GHashTable *Ahash, GError **Aerror);
 extern gboolean maj_drive_info(Tdriveinfo *Adrive, gchar *Adev, GError **Aerror);
 extern gboolean perform_erase_cdrw(GHashTable *Ahash, GError **Aerror);
 extern gboolean perform_fix_cd(GHashTable *Ahash, GError **Aerror);
+extern void eject_cd(gchar *Adev, GError **Aerror);
 
 /* mkisofs.c */
 extern gchar *make_image_getextrapara(GHashTable *Ahash);
@@ -425,6 +437,9 @@ extern gboolean quit_property(GtkWidget *Awidget, GdkEvent *Aevent, gpointer Ada
 extern gboolean on_deleteevent_gravure(GtkWidget *Awidget, GdkEvent *Aevent, gpointer Adata);
 extern void gtk_display_switchstatusbar(GtkWidget *Abtn, gpointer Adata);
 extern void gtk_display_updatesize(GtkWidget *Abtn, gpointer Adata);
+extern void popup_formatdvdrw(GtkWidget *Abtn, gpointer Adata);
+extern void gtk_confirm_dvdoperation(GtkWidget *Abtn, gpointer Adata);
+
 /*
  * vim:et:ts=8:sts=2:sw=2
  */
