@@ -47,7 +47,7 @@ Tmediaentry Gdefaultmedia[] = {
 };
 #endif
 
-Tmyentry Gtypecdaudio[] = {
+static Tmyentry Gtypecdaudio[] = {
   { "1260", N_("21 min"), FALSE },
   { "1380", N_("23 min"), FALSE },
   { "4440", N_("74 min"), FALSE },
@@ -58,7 +58,7 @@ Tmyentry Gtypecdaudio[] = {
   { NULL }
 };
 
-Tmyentry Gtypecddata[] = {
+static Tmyentry Gtypecddata[] = {
   { "180", N_("180 mb"), FALSE },
   { "202", N_("202 mb"), FALSE },
   { "650", N_("650 mb"), FALSE },
@@ -69,13 +69,22 @@ Tmyentry Gtypecddata[] = {
   { NULL }
 };
 
-Tmyentry Gtypeunit[] = {
+static Tmyentry Gtypeicosize[] = {
+  { "16", N_("16x16 px"), FALSE },
+  { "24", N_("24x24 px"), FALSE },
+  { "32", N_("32x32 px"), FALSE },
+  { "48", N_("48x48 px"), FALSE },
+  { NULL }
+};
+
+/*
+static Tmyentry Gtypeunit[] = {
   { "kb", N_("kb"), TRUE },
   { "mb", N_("mb"), FALSE },
   { "gb", N_("gb"), FALSE },
-};
+};*/
 
-Tmyentry Gmodburn[] = {
+static Tmyentry Gmodburn[] = {
     { "dao", N_("Disk At Once - DAO (default)"), TRUE },
     { "tao", N_("Track At Once  - TAO"), FALSE },
     { "raw96r", N_("RAW writing - raw96r"), FALSE },
@@ -84,37 +93,32 @@ Tmyentry Gmodburn[] = {
     { NULL }
   };
 
-Tmyentry Gisolevel[] = {
+static Tmyentry Gisolevel[] = {
   { "1", N_("ISO 9660 level 1"), FALSE },
   { "2", N_("ISO 9660 level 2 (default)"), TRUE },
   { "3", N_("ISO 9660 level 3"), FALSE },
   { NULL }
 };
 
-Tmyentry Gformatcd[] = {
-    { "mode1", N_("CD-Rom Mode 1 (default)"), TRUE},
+static Tmyentry Gformatcd[] = {
+    { "data", N_("CD-Rom Mode 1 (default)"), TRUE},
     { "mode2", N_("CD-Rom Mode 2"), FALSE },
     { "xa1", N_("CD-Rom XA Mode 1"), FALSE },
     { "xa2", N_("CD-Rom XA Mode 2"), FALSE },
     { NULL }
   };
 
-GdkPixbuf *GDirIcone, *GFileIcone, *GCDIcone, *GAudioIcone, *GCDRWIcone, *GCDpetiteIcone,
-  *GCDRWpetiteIcone, *GpetiteGraver, *GGraver, *GISOpetiteIcone, *GEraseCdrw, *GFileImage;
-
-void remplirecombovitesse(GtkComboBox *Acombo, gchar *Alecident)
+void remplirecombovitesse(GtkComboBox *Acombo, gchar *Alecident, gchar *Aselvalue)
 {
   GtkListStore *Ldata = GTK_LIST_STORE(gtk_combo_box_get_model(Acombo));
   gchar *Llabel, *Lident;  
   gint i;
   gint passe = 0;
   GtkTreeIter Liter;
-  gint Ldef = 0;
-  gboolean Lactive = FALSE;
   gint Lmaxspeed = MAX_SPEED;
-  const gchar *Ldefspeed = g_getenv("CDR_SPEED");
+  gboolean Lselok = FALSE;
 
-  if (Ldefspeed && *Ldefspeed) Ldef = atoi(Ldefspeed);
+  
 
   if (Alecident && *Alecident) {
     Tdriveinfo *Lundrive = find_drive(Alecident);
@@ -131,7 +135,14 @@ void remplirecombovitesse(GtkComboBox *Acombo, gchar *Alecident)
     Lident = g_strdup_printf("%d", i);    
     gtk_list_store_append(Ldata, &Liter);
     gtk_list_store_set(Ldata, &Liter, 0, Lident, 1, Llabel, -1);
-    if (Ldef == i) { gtk_combo_box_set_active_iter(Acombo, &Liter); Lactive = TRUE; }
+
+    if (Aselvalue && *Aselvalue && Lselok == FALSE) {
+      if (!strcmp(Lident, Aselvalue)) {
+        gtk_combo_box_set_active_iter(Acombo, &Liter);
+        Lselok = TRUE;
+      }
+    }
+
     g_free(Llabel); g_free(Lident);
     
     if (i >= Lmaxspeed) break;
@@ -139,15 +150,17 @@ void remplirecombovitesse(GtkComboBox *Acombo, gchar *Alecident)
 
   gtk_list_store_append(Ldata, &Liter);
   gtk_list_store_set(Ldata, &Liter, 0, "0", 1, _("Full speed"), -1);
-  if (Lactive == FALSE) gtk_combo_box_set_active_iter(Acombo, &Liter);
+  
+  if (Lselok == FALSE) gtk_combo_box_set_active_iter(Acombo, &Liter);
 }
 
-void remplirecombo (GtkComboBox *Acombo, gchar *Abasename, Tmyentry *Aentry, gboolean Adoinit)
+void remplirecombo (GtkComboBox *Acombo, gchar *Abasename, Tmyentry *Aentry, gboolean Adoinit, gchar *Aselvalue)
 {
   GtkListStore *Ldata;
   gchar *Lident;
   Tmyentry *Lcurentry;
   GtkTreeIter Liter;
+  gboolean Lselok = FALSE;
 
   if (Adoinit == FALSE) {
     Ldata = GTK_LIST_STORE(gtk_combo_box_get_model(Acombo));
@@ -169,20 +182,35 @@ void remplirecombo (GtkComboBox *Acombo, gchar *Abasename, Tmyentry *Aentry, gbo
   for (Lcurentry = Aentry; Lcurentry->label; Lcurentry++) {
     Lident = g_strdup_printf("%s%s", Abasename, Lcurentry->basecode);
     gtk_list_store_append(Ldata, &Liter);
-    gtk_list_store_set(Ldata, &Liter, 0, Lident, 1, Lcurentry->label, -1); 
+    gtk_list_store_set(Ldata, &Liter, 0, Lident, 1, _(Lcurentry->label), -1); 
+
+    if (!Aselvalue || !*Aselvalue) {
+      if (Lcurentry->defaut == TRUE) {
+        gtk_combo_box_set_active_iter(Acombo, &Liter);
+        Lselok = TRUE;
+      }
+    } else {
+      if (!strcmp(Aselvalue, Lident)) { 
+        gtk_combo_box_set_active_iter(Acombo, &Liter);
+        Lselok = TRUE;
+      }
+    }
     g_free(Lident);
-    if (Lcurentry->defaut == TRUE) gtk_combo_box_set_active_iter(Acombo, &Liter);
   }
+
+  /* si pas de selection alors on met le premier par defaut */
+  if (Lselok == FALSE) gtk_combo_box_set_active(Acombo, 0);
 }
 
-void remplirecombograveur(GtkComboBox *Acombo, gint Aquoi)
+void remplirecombograveur(GtkComboBox *Acombo, gint Aquoi, gchar *Aselvalue)
 {
   GtkListStore *Ldata = GTK_LIST_STORE(gtk_combo_box_get_model(Acombo));
-  gboolean Lpremier = FALSE;
   GtkTreeIter Liter;
   GSList *Lcur;
   Tdriveinfo *Ldrive;
   gint i;
+  gboolean Lselok = FALSE;
+  gchar *Lcurdrive;
 
   gtk_list_store_clear(Ldata);
  
@@ -192,19 +220,31 @@ void remplirecombograveur(GtkComboBox *Acombo, gint Aquoi)
     
     gtk_list_store_append(Ldata, &Liter);
 
-    gtk_list_store_set(Ldata, &Liter, 0, (gchar *)g_slist_nth_data(Ldrive->dev, Ldrive->actuperiph), 1, 
+    Lcurdrive =g_slist_nth_data(Ldrive->dev, Ldrive->actuperiph);
+    
+    gtk_list_store_set(Ldata, &Liter, 0, Lcurdrive, 1, 
       DRIVE_ICONE(Ldrive), 2, Ldrive->name, 3, i, -1);
     
-    if (Lpremier == FALSE) {      
-      Lpremier = TRUE;
-      gtk_combo_box_set_active_iter(Acombo, &Liter);
+    if (Aselvalue && *Aselvalue && Lselok==FALSE) {
+      if (!strcmp(Aselvalue, Lcurdrive)) { 
+        gtk_combo_box_set_active_iter(Acombo, &Liter); 
+        Lselok = TRUE;
+      }
     }
   }
   
-  if (Aquoi & ISO) {    
+  if (Aquoi & ISO) { 
     gtk_list_store_append(Ldata, &Liter);
-    gtk_list_store_set(Ldata, &Liter, 0, "iso", 1, GISOpetiteIcone, 2, _("ISO file..."), 3, 0, -1);
-  }  
+    gtk_list_store_set(Ldata, &Liter, 0, "iso", 1, GISOpetiteIcone, 2, _("ISO file..."), 3, -1, -1);
+
+    if (Aselvalue && Lselok==FALSE && !strcmp(Aselvalue, "iso")) {
+      gtk_combo_box_set_active_iter(Acombo, &Liter); 
+      Lselok = TRUE;
+    }
+  }
+
+/* si pas de selection alors on met le premier par defaut */
+  if (Lselok == FALSE) gtk_combo_box_set_active(Acombo, 0);
 }
 
 void remplirelistegraveur(GtkTreeView *Aliste)
@@ -268,6 +308,14 @@ GtkMenu *create_gtkpopupmenudevices(GtkWidget *Aliste, GHashTable *Ahash)
   return Lmenu;
 }
 
+/* menu popup sur le formatage d'un dvd */
+GtkMenu *create_gtkpopupmenuformatdvd(GHashTable *Ahash)
+{
+  GtkMenu *Lmenu = GTK_MENU(g_hash_table_lookup(Ahash, "popupformatdvd"));
+
+  return Lmenu;
+}
+
 /* menu popup sur les pistes audio */
 GtkMenu *create_gtkpopupmenuaudio(GtkWidget *Aliste, GHashTable *Ahash)
 {
@@ -291,6 +339,31 @@ GtkMenu *create_gtkpopupmenuaudio(GtkWidget *Aliste, GHashTable *Ahash)
   return Lmenu;
 }
 
+/* creation popup "affichage" */
+GtkMenu *create_gtkpopupmenudisplay(GtkWidget *Aliste, GHashTable *Ahash)
+{
+  GtkMenu *Lmenu = GTK_MENU(g_hash_table_lookup(Ahash, "popupdisplay"));
+  gboolean Ldispsb = conf_get_boolean("statusbar");
+  GtkWidget *Litem, *Litem2;
+  
+
+  Litem = g_hash_table_lookup(Ahash, "popupdisp_showstatusbar");
+  Litem2 = g_hash_table_lookup(Ahash, "popupdisp_hidestatusbar");
+  if (Ldispsb) {
+    gtk_widget_hide(Litem);
+    gtk_widget_show(Litem2);
+  } else {
+    gtk_widget_show(Litem);
+    gtk_widget_hide(Litem2);
+  }
+
+  Litem = sc_hash_table_lookupv(Ahash, "popupdisp_iconsize_%s", conf_get_string("iconsize"));
+  if (GTK_IS_WIDGET(Litem)) gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(Litem), TRUE);
+  
+  return Lmenu;
+}
+
+/* creation popup "data" */
 GtkMenu *create_gtkpopupmenudata(GtkWidget *Aliste, GHashTable *Ahash)
 {
   GtkMenu *Lmenu = GTK_MENU(g_hash_table_lookup(Ahash, "popupdata"));
@@ -463,6 +536,30 @@ void prepare_popups(GladeXML *Axml, GHashTable *Ahash)
       "activate", G_CALLBACK(gtk_def_imageboot), Ahash);
 #endif
 
+  /* popup affichage */
+  glade_to_hash(Axml, Ahash, "popupdisplay");
+  g_signal_connect(G_OBJECT(glade_to_hash(Axml, Ahash, "popupdisp_iconsize_48")),
+      "activate", G_CALLBACK(gtk_display_updatesize), Ahash);
+  g_signal_connect(G_OBJECT(glade_to_hash(Axml, Ahash, "popupdisp_iconsize_32")),
+      "activate", G_CALLBACK(gtk_display_updatesize), Ahash);
+  g_signal_connect(G_OBJECT(glade_to_hash(Axml, Ahash, "popupdisp_iconsize_24")),
+      "activate", G_CALLBACK(gtk_display_updatesize), Ahash);
+  g_signal_connect(G_OBJECT(glade_to_hash(Axml, Ahash, "popupdisp_iconsize_16")),
+      "activate", G_CALLBACK(gtk_display_updatesize), Ahash);
+
+  g_signal_connect(G_OBJECT(glade_to_hash(Axml, Ahash, "popupdisp_showstatusbar")),
+      "activate", G_CALLBACK(gtk_display_switchstatusbar), Ahash);
+  g_signal_connect(G_OBJECT(glade_to_hash(Axml, Ahash, "popupdisp_hidestatusbar")),
+      "activate", G_CALLBACK(gtk_display_switchstatusbar), Ahash);
+
+  /* popup formater un dvd */
+  glade_to_hash(Axml, Ahash, "popupformatdvd");
+  g_signal_connect(G_OBJECT(glade_to_hash(Axml, Ahash, "popupform_format")),
+      "activate", G_CALLBACK(gtk_confirm_dvdoperation), Ahash);
+  g_signal_connect(G_OBJECT(glade_to_hash(Axml, Ahash, "popupform_blank")),
+      "activate", G_CALLBACK(gtk_confirm_dvdoperation), Ahash);
+  g_signal_connect(G_OBJECT(glade_to_hash(Axml, Ahash, "popupform_blankfull")),
+      "activate", G_CALLBACK(gtk_confirm_dvdoperation), Ahash);
 }
 
 GtkAlignment *new_seliso(gchar *Aname, GtkWidget *Aparent)
@@ -519,10 +616,9 @@ GtkWidget* manage_main_window (guint32 *Aaudiolen, guint32 *Aaudiomaxlen,
   GtkWidget *Lwindow;
   GtkNotebook *Lbodycdaudio, *Lbodycddata, *Lbodycdcopy, *Lbodycdother;
   GtkHBox *Lmainbody;
-  GtkToggleButton *Ltogbtnaudio, *Ltogbtncopy, *Ltogbtnother, *Ltogbtndata;
   GtkComboBox *Lcombo;
-  GtkButton *Lbtnerasecdrw;
-  GtkTreeView *Ltreeaudio, *Ltreedata;
+  GtkButton *Lbtnerasecdrw, *Lbtnformatdvdrw;
+  GtkTreeView *Ltreeaudio, *Ltreedata, *Ltopmenu;
   GHashTable *Lhash = _hash();
 
   if (!Lxml) {
@@ -546,22 +642,20 @@ GtkWidget* manage_main_window (guint32 *Aaudiolen, guint32 *Aaudiomaxlen,
   gtk_widget_reparent(GTK_WIDGET(Lbodycdcopy), GTK_WIDGET(Lmainbody));
   Lbodycdother = GTK_NOTEBOOK(glade_to_hash(Lxml, Lhash, "bodycdother"));
   gtk_widget_reparent(GTK_WIDGET(Lbodycdother), GTK_WIDGET(Lmainbody));
+  g_hash_table_replace(Lhash, "_lstclicked", Lbodycdaudio);
 
   /* mise a jour des label lorsque l'on change d'onglet dans la partie "graver un cd de donnee" */
   g_signal_connect(G_OBJECT(Lbodycddata), "switch-page", G_CALLBACK(switchpage), Lhash);
 
   /* bouttons barre de gauche */
-  Ltogbtndata = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "btncddata"));
-  g_signal_connect(G_OBJECT(Ltogbtndata), "toggled", G_CALLBACK(changemenu), Lhash);
-  Ltogbtncopy = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "btncdcopy"));
-  g_signal_connect(G_OBJECT(Ltogbtncopy), "toggled", G_CALLBACK(changemenu), Lhash);
-  Ltogbtnother = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "btncdother"));
-  g_signal_connect(G_OBJECT(Ltogbtnother), "toggled", G_CALLBACK(changemenu), Lhash);
-  Ltogbtnaudio = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "btncdaudio"));
-  g_signal_connect(G_OBJECT(Ltogbtnaudio), "toggled", G_CALLBACK(changemenu), Lhash);
+  Ltopmenu = GTK_TREE_VIEW(glade_to_hash(Lxml, Lhash, "topmenu"));
+  glade_to_hash(Lxml, Lhash, "statusbar");
+
+  manage_top_menu(Lhash, MENU_NEW);
+  update_status_bar_display(Lhash);
+  g_signal_connect(G_OBJECT(Ltopmenu), "button-press-event", G_CALLBACK(gtk_do_eventbuttonpress), Lhash);
+  g_signal_connect(G_OBJECT(Ltopmenu), "popup-menu", G_CALLBACK(key_popupmenu_display), Lhash);
 
-  /* activation onglet "cd audio" par defaut */
-  gtk_toggle_button_set_active(Ltogbtnaudio, TRUE);
 
   /* signaux sur le menu */
   g_signal_connect(G_OBJECT(glade_xml_get_widget(Lxml, "menustartnew")), "activate",
@@ -591,7 +685,7 @@ GtkWidget* manage_main_window (guint32 *Aaudiolen, guint32 *Aaudiomaxlen,
   glade_to_hash(Lxml, Lhash, "dstdatatable");
 
   /* onglet graver un cd audio */
-  glade_to_hash_list(Lxml, Lhash, "audiosimul", "audionotfix", "nbrcdaudio", NULL);
+  glade_to_hash_list(Lxml, Lhash, "audiosimul", "audionotfix", "audiodao", "nbrcdaudio", NULL);
 
   /* onglet graver un cd de donnee */
   glade_to_hash_list(Lxml, Lhash, "datavoli", "datapubl", "dataprep", "databibl", "datacopy", "dataabst",
@@ -612,23 +706,27 @@ GtkWidget* manage_main_window (guint32 *Aaudiolen, guint32 *Aaudiomaxlen,
   prepare_disable_when_iso(Lhash, "dstcopycombo", "nbrcdcopy", "copysimul", NULL);
 
   Lbtnerasecdrw = GTK_BUTTON(glade_to_hash(Lxml, Lhash, "btnerasecdrwother1"));
+  Lbtnformatdvdrw = GTK_BUTTON(glade_to_hash(Lxml, Lhash, "btnformatdvdrwother1"));
   prepare_combobox_graveur(Lxml, Lhash, "dstother");
-  prepare_disable_when_notcdrw(Lhash, "dstothercombo", "btnerasecdrwother1", NULL);
-
+  prepare_disable_when(Lhash, "dstothercombo_notcdrw", "btnerasecdrwother1", NULL);
+  prepare_disable_when(Lhash, "dstothercombo_notdvdrw", "btnformatdvdrwother1", NULL);
   
   update_combo_graveur(Lhash);
 
 
   /* on rempli les autres combo */
-  remplirecombo(GTK_COMBO_BOX(glade_to_hash(Lxml, Lhash, "dataformat")), "", Gformatcd, TRUE);
-  remplirecombo(GTK_COMBO_BOX(glade_to_hash(Lxml, Lhash, "datamodburn")), "", Gmodburn, TRUE);
-  remplirecombo(GTK_COMBO_BOX(glade_to_hash(Lxml, Lhash, "dataisolevel")), "", Gisolevel, TRUE);
+  remplirecombo(GTK_COMBO_BOX(glade_to_hash(Lxml, Lhash, "dataformat")), "", Gformatcd,
+      TRUE, conf_get_string("dataformat"));
+  remplirecombo(GTK_COMBO_BOX(glade_to_hash(Lxml, Lhash, "datamodburn")), "", Gmodburn,
+      TRUE, conf_get_string("datamodburn"));
+  remplirecombo(GTK_COMBO_BOX(glade_to_hash(Lxml, Lhash, "dataisolevel")), "", Gisolevel,
+      TRUE, conf_get_string("dataisolevel"));
   Lcombo = GTK_COMBO_BOX(glade_to_hash(Lxml, Lhash, "listeremplidata"));
-  remplirecombo(Lcombo, "", Gtypecddata, TRUE); 
+  remplirecombo(Lcombo, "", Gtypecddata, TRUE, conf_get_string("listeremplidata")); 
   g_signal_connect(G_OBJECT(Lcombo), "changed", G_CALLBACK(change_remplissage), Lhash);
 
   Lcombo = GTK_COMBO_BOX(glade_to_hash(Lxml, Lhash, "listerempliaudio"));
-  remplirecombo(Lcombo, "", Gtypecdaudio, TRUE);
+  remplirecombo(Lcombo, "", Gtypecdaudio, TRUE, conf_get_string("listerempliaudio"));
   g_signal_connect(G_OBJECT(Lcombo), "changed", G_CALLBACK(change_remplissage), Lhash);
  
   /* boutons "page suivante" */
@@ -644,6 +742,7 @@ GtkWidget* manage_main_window (guint32 *Aaudiolen, guint32 *Aaudiomaxlen,
 
   /* boutons de la page "autres operations" */
   g_signal_connect(G_OBJECT(Lbtnerasecdrw), "clicked", G_CALLBACK(confirm_erasecdrw), Lhash);
+  g_signal_connect(G_OBJECT(Lbtnformatdvdrw), "clicked", G_CALLBACK(popup_formatdvdrw), Lhash);
   g_signal_connect(G_OBJECT(glade_xml_get_widget(Lxml, "btnfixcdother1")), "clicked", G_CALLBACK(confirm_fixcd), Lhash);
   
   
@@ -692,6 +791,9 @@ GtkWidget* manage_main_window (guint32 *Aaudiolen, guint32 *Aaudiomaxlen,
   /* on restaure la taille et la position que la fenetre avait lors de la derniere utilisation */ 
   restore_main_window_pos(Lwindow); 
 
+  /* on restaure les dernieres valeurs utilisees pour certains champs */
+  restore_last_used_values(Lhash);
+  
   gtk_widget_show(Lwindow);
 
   return Lwindow;
@@ -705,21 +807,16 @@ void update_combo_graveur(GHashTable *Ahash)
   GtkComboBox *Ldstdatacombo = GTK_COMBO_BOX(g_hash_table_lookup(Ahash, "dstdatacombo"));
   GtkComboBox *Ldstaudiocombo = GTK_COMBO_BOX(g_hash_table_lookup(Ahash, "dstaudiocombo"));
   GtkComboBox *Ldstothercombo = GTK_COMBO_BOX(g_hash_table_lookup(Ahash, "dstothercombo"));
-  
-  remplirecombograveur(Lsrccopycombo, ALL + ISO);
-  on_selectgraveur(GTK_WIDGET(Lsrccopycombo), Ahash);
-  
-  remplirecombograveur(Ldstcopycombo, GRAVEUR_ONLY + ISO);
-  on_selectgraveur(GTK_WIDGET(Ldstcopycombo), Ahash);
-  
-  remplirecombograveur(Ldstdatacombo, GRAVEUR_ONLY + ISO);
-  on_selectgraveur(GTK_WIDGET(Ldstdatacombo), Ahash);
-  
-  remplirecombograveur(Ldstaudiocombo, GRAVEUR_ONLY);
-  on_selectgraveur(GTK_WIDGET(Ldstaudiocombo), Ahash);
 
-  remplirecombograveur(Ldstothercombo, GRAVEUR_ONLY);
-  on_selectgraveur(GTK_WIDGET(Ldstothercombo), Ahash);
+  remplirecombograveur(Lsrccopycombo, ALL + ISO, conf_get_string("srccopycombo"));
+  
+  remplirecombograveur(Ldstcopycombo, GRAVEUR_ONLY + ISO, conf_get_string("dstcopycombo"));
+  
+  remplirecombograveur(Ldstdatacombo, GRAVEUR_ONLY + ISO, conf_get_string("dstdatacombo"));
+  
+  remplirecombograveur(Ldstaudiocombo, GRAVEUR_ONLY, conf_get_string("dstaudiocombo"));
+
+  remplirecombograveur(Ldstothercombo, GRAVEUR_ONLY, conf_get_string("dstothercombo"));
 }
 
 GtkWidget* create_fileselection1 (GtkWindow *AParent, GtkFileChooserAction AType)
@@ -839,22 +936,22 @@ GtkWidget* create_addpisteselection (GtkWindow *AParent)
 
 GtkWidget* create_adddirselection (GtkWindow *AParent)
 {
-  GtkWidget *fileselection1;
-  GtkFileFilter *filterall;
+  GtkWidget *Lfileselection;
+  GtkFileFilter *Lfilterall;
 
   /* filtres pour la selection de fichiers */
-  filterall = gtk_file_filter_new ();
-  gtk_file_filter_set_name (filterall, _("All files (*.*)"));
-  gtk_file_filter_add_pattern(filterall, "*");
-  fileselection1 = gtk_file_chooser_dialog_new(_("Select a directory to add"),
+  Lfilterall = gtk_file_filter_new ();
+  gtk_file_filter_set_name (Lfilterall, _("All files (*.*)"));
+  gtk_file_filter_add_pattern(Lfilterall, "*");
+  Lfileselection = gtk_file_chooser_dialog_new(_("Select a directory to add"),
       AParent, GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
       GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
 
-  gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(fileselection1), TRUE);
-  gtk_dialog_set_default_response (GTK_DIALOG (fileselection1), GTK_RESPONSE_ACCEPT);
-  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (fileselection1), filterall);
+  gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(Lfileselection), TRUE);
+  gtk_dialog_set_default_response (GTK_DIALOG (Lfileselection), GTK_RESPONSE_ACCEPT);
+  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (Lfileselection), Lfilterall);
 
-  return fileselection1;
+  return Lfileselection;
 }
 
 /* boite de dialogue "edition media" */
@@ -953,7 +1050,7 @@ void about_graveman (void)
 
   Llabelversion = GTK_LABEL(glade_xml_get_widget(Lxml, "version"));
 
-  Ltmp = g_strdup_printf(_("version %s"), VERSION);
+  Ltmp = g_strdup_printf(_("version %s - http://www.nongnu.org/graveman"), VERSION);
   gtk_label_set_label(Llabelversion, Ltmp);
   g_free(Ltmp);
 
@@ -979,6 +1076,7 @@ void show_graverwindow (GHashTable *Ahash, gchar *Aaction, gchar *Atitle)
   gboolean Lbackvalue = FALSE;
   gint Lcont = 1;
   GtkWidget *Lstatusbox = NULL;
+  GtkWidget *Lparent = GTK_WIDGET(g_hash_table_lookup(Ahash, "topwindow"));
   GError *Lerror = NULL;
 
   if (!Lxml) {
@@ -986,6 +1084,7 @@ void show_graverwindow (GHashTable *Ahash, gchar *Aaction, gchar *Atitle)
   }
 
   Lwindowburn = glade_xml_get_widget(Lxml, "window_burn"); 
+  gtk_window_set_transient_for(GTK_WINDOW(Lwindowburn), GTK_WINDOW(Lparent));
 
   /* titres avancement */
   Ltitle = GTK_LABEL(glade_to_hash(Lxml, Ahash, "gravetitle"));
@@ -1115,12 +1214,12 @@ void prepare_disable_when_iso(GHashTable *Ahash, gchar *Abasename, const gchar *
 }
 
 /* objets a cacher lorsque l'on selectionne une image iso en tant que source ou destination */
-void prepare_disable_when_notcdrw(GHashTable *Ahash, gchar *Abasename, const gchar *Afirst, ...)
+void prepare_disable_when(GHashTable *Ahash, gchar *Abasename, const gchar *Afirst, ...)
 {
   va_list Largs;
   gchar *Lbuf = (gchar *) Afirst;
   gint Lnbr = 0;
-  gchar *Lname = g_strdup_printf("%s_notcdrwtodisabled%d", Abasename, Lnbr++);
+  gchar *Lname = g_strdup_printf("%stodisabled%d", Abasename, Lnbr++);
   gchar *Lcur;
 
   g_hash_table_insert(Ahash, Lname, g_hash_table_lookup(Ahash, Afirst));
@@ -1129,15 +1228,108 @@ void prepare_disable_when_notcdrw(GHashTable *Ahash, gchar *Abasename, const gch
   while (*Lbuf++) {
     if (!(Lcur = va_arg(Largs, gchar *))) break;
     
-    Lname = g_strdup_printf("%s_notcdrwtodisabled%d", Abasename, Lnbr++);
+    Lname = g_strdup_printf("%stodisabled%d", Abasename, Lnbr++);
     g_hash_table_insert(Ahash, Lname, g_hash_table_lookup(Ahash, Lcur));
   }
 
   va_end(Largs);
 } 
 
+void gtk_toggle_top_menu(GtkTreeView *Atopmenu, gpointer Adata)
+{
+  GHashTable *Lhash = (GHashTable *)Adata;
+  GtkTreeModel *Ltreemodel = gtk_tree_view_get_model(Atopmenu);
+  GtkTreeIter Liter;
+  gchar *Lident;
+  GtkNotebook *Llstclick = g_hash_table_lookup(Lhash, "_lstclicked"); /* dernier element ayant eu le focus */
+  GtkNotebook *Lnewclick;
+  GtkTreeSelection *Lselection = gtk_tree_view_get_selection(Atopmenu);
 
-/*void prepare_combobox_graveur(GtkComboBox *Acombobox, GHashTable *Ahash)*/
+  if (!gtk_tree_selection_get_selected(Lselection, &Ltreemodel, &Liter)) return;
+
+  gtk_tree_model_get(Ltreemodel, &Liter, 0, &Lident, -1);
+
+  Lnewclick = g_hash_table_lookup(Lhash, Lident);
+  if (GTK_IS_NOTEBOOK(Lnewclick)) {
+  
+    if (GTK_IS_NOTEBOOK(Llstclick)) {
+      gtk_widget_hide(GTK_WIDGET(Llstclick));
+    }
+    g_hash_table_replace(Lhash, "_lstclicked", Lnewclick);
+
+    gtk_widget_show(GTK_WIDGET(Lnewclick));
+  }
+    
+  g_free(Lident);
+}
+
+/* status bar */
+void update_status_bar_display(GHashTable *Ahash)
+{
+  gboolean Ldispsb = conf_get_boolean("statusbar");
+  GtkWidget *Ldisp = g_hash_table_lookup(Ahash, "statusbar");
+
+  if (Ldispsb) {
+    gtk_widget_show(Ldisp);
+  } else {
+    gtk_widget_hide(Ldisp);
+  }
+}
+
+/* bar menu de gauche */
+void manage_top_menu(GHashTable *Ahash, gint Aaction)
+{
+  GtkListStore *Lmodel;
+  GtkTreeView *Ltopmenu = g_hash_table_lookup(Ahash, "topmenu");
+  GtkTreeSelection *Lselection = gtk_tree_view_get_selection(Ltopmenu);
+  GtkTreeIter Liter;
+  GtkCellRenderer *Lcellrender;
+  GtkTreeViewColumn *Lcell;
+
+  if (Aaction == MENU_NEW) {
+    Lmodel = gtk_list_store_new(3, G_TYPE_STRING, GDK_TYPE_PIXBUF, G_TYPE_STRING);
+    gtk_tree_selection_set_mode(Lselection, GTK_SELECTION_BROWSE);
+    gtk_tree_view_set_model(Ltopmenu, GTK_TREE_MODEL(Lmodel));
+
+    /* creation colonnes */
+    Lcellrender = gtk_cell_renderer_pixbuf_new();
+    Lcell = gtk_tree_view_column_new_with_attributes("", Lcellrender, "pixbuf", 1, NULL);
+     gtk_tree_view_append_column(GTK_TREE_VIEW(Ltopmenu), Lcell);
+	
+    Lcellrender = gtk_cell_renderer_pixbuf_new();
+    Lcellrender = gtk_cell_renderer_text_new();
+    Lcell = gtk_tree_view_column_new_with_attributes("", Lcellrender, "text", 2, NULL);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(Ltopmenu), Lcell);
+    Lcellrender = gtk_cell_renderer_pixbuf_new();
+
+    g_signal_connect(G_OBJECT(Ltopmenu), "cursor-changed", G_CALLBACK(gtk_toggle_top_menu), Ahash); 
+  } else {
+    Lmodel = GTK_LIST_STORE(gtk_tree_view_get_model(Ltopmenu));
+    gtk_list_store_clear(Lmodel);
+  }
+
+  /* les icones en elles meme */
+  prepare_menu_images(Ahash);
+
+  gtk_list_store_append(Lmodel, &Liter);
+  gtk_list_store_set(Lmodel, &Liter, 0, "bodycdaudio", 1, GMenuAudio, 2, _("Audio CD"), -1);
+  gtk_tree_selection_select_iter(Lselection, &Liter);
+  gtk_toggle_top_menu(Ltopmenu, Ahash);
+
+  gtk_list_store_append(Lmodel, &Liter);
+  gtk_list_store_set(Lmodel, &Liter, 0, "bodycddata", 1, GMenuData, 2, _("Data CD"), -1);
+
+  gtk_list_store_append(Lmodel, &Liter);
+  gtk_list_store_set(Lmodel, &Liter, 0, "bodycdcopy", 1, GMenuCopy, 2, _("Duplicate CD"), -1);
+
+  gtk_list_store_append(Lmodel, &Liter);
+  gtk_list_store_set(Lmodel, &Liter, 0, "bodycdother", 1, GMenuOther, 2, _("Other operations"), -1);
+ 
+  gtk_tree_view_columns_autosize(Ltopmenu); 
+}
+
+    
+/* preparation du combo contenant la liste du peripherique a utiliser */
 void prepare_combobox_graveur(GladeXML *Axml, GHashTable *Ahash, gchar *Abasename)
 {
   GtkComboBox *Lcombobox = GTK_COMBO_BOX(glade_to_hashv(Axml, Ahash, "%scombo", Abasename));
@@ -1239,8 +1431,8 @@ void prepare_properties_devicestreeview(GtkTreeView *Atreeview)
 void prepare_listeaudio(GtkTreeView *Atreeaudio)
 {
   GtkTreeSelection *Lselection = gtk_tree_view_get_selection(GTK_TREE_VIEW(Atreeaudio));
-  GtkListStore *Lmodel = gtk_list_store_new(6, G_TYPE_INT, GDK_TYPE_PIXBUF, G_TYPE_STRING,
-                        G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT);
+  GtkListStore *Lmodel = gtk_list_store_new(7, G_TYPE_INT, GDK_TYPE_PIXBUF, G_TYPE_STRING,
+                        G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT);
   GtkCellRenderer *Lcellrender;
   GtkTreeViewColumn *Lcell;
 
@@ -1269,8 +1461,8 @@ void prepare_listeaudio(GtkTreeView *Atreeaudio)
 void prepare_listedata(GtkTreeView *Atreedata)
 {
   GtkTreeSelection *Lselection = gtk_tree_view_get_selection(GTK_TREE_VIEW(Atreedata));
-  GtkTreeStore *Lmodel = gtk_tree_store_new(6, G_TYPE_INT, GDK_TYPE_PIXBUF, G_TYPE_STRING,
-                                G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT);
+  GtkTreeStore *Lmodel = gtk_tree_store_new(7, G_TYPE_INT, GDK_TYPE_PIXBUF, G_TYPE_STRING,
+                                G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT);
   GtkTreeIter Liter;
   GtkCellRenderer *Lcellrender;
   GtkTreeViewColumn *Lcell;
@@ -1297,7 +1489,42 @@ void prepare_listedata(GtkTreeView *Atreedata)
 
   /* icone de base dans la liste des fichiers */
   gtk_tree_store_append(GTK_TREE_STORE(Lmodel), &Liter, NULL);
-  gtk_tree_store_set(Lmodel, &Liter, 0, TYPE_CD, 1, GCDpetiteIcone, 2, _("New CD"), 3, "", 4, "", 5, 0, -1);
+  gtk_tree_store_set(Lmodel, &Liter, 0, TYPE_CD, 1, GCDpetiteIcone, 2, _("New CD"), 3, "", 4, "", 5, "", 6, 0, -1);
+}
+
+/* fenetre de confirmation avec une checkbox */
+GHashTable *create_dialog_confirm_operation (GtkWidget *Aparent,
+    gchar *Alabel, gchar *Acheckboxlbl, gboolean Acheckboxstatus)
+{
+  gchar *Ltemplate = PACKAGE_DATA_DIR "/" PACKAGE "/dialog_confirm_operation.glade";
+  GladeXML *Lxml = glade_xml_new(Ltemplate, NULL,NULL);
+  GtkWidget *Ldialog;
+  GtkLabel *Llabel;
+  GtkToggleButton *Ltoggleoption;
+  GHashTable *Lhash = _hash();
+
+  if (!Lxml) {
+    g_error("Cannot load '%s': %s\n", Ltemplate, g_strerror(errno));
+  }
+
+  Ldialog = glade_xml_get_widget(Lxml, "dialog_confirm_operation");
+  gtk_window_set_transient_for(GTK_WINDOW(Ldialog), GTK_WINDOW(Aparent));
+  g_hash_table_insert(Lhash, "window", Ldialog);
+
+  /* titre */
+  Llabel = GTK_LABEL(glade_to_hash(Lxml, Lhash, "label"));
+  gtk_label_set_text(Llabel, Alabel);
+  
+  /* effacer les cdrw en mode fast ? */
+  Ltoggleoption = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "checkbox"));
+  if (Acheckboxlbl) {
+    gtk_toggle_button_set_active(Ltoggleoption, Acheckboxstatus);
+    gtk_button_set_label(GTK_BUTTON(Ltoggleoption), Acheckboxlbl);
+  } else {
+    gtk_widget_hide(GTK_WIDGET(Ltoggleoption));
+  }
+
+  return Lhash;
 }
 
 /* fenetre proprietes */
@@ -1326,6 +1553,10 @@ GHashTable *create_dialog_proprietes (GtkWidget *Aparent)
   Ltoggleoption = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "overburn"));
   gtk_toggle_button_set_active(Ltoggleoption, conf_get_boolean("overburn"));
 
+  /* effacer les cdrw avant ecriture */
+  Ltoggleoption = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "autoblank"));
+  gtk_toggle_button_set_active(Ltoggleoption, conf_get_boolean("autoblank"));
+
   /* effacer les cdrw en mode fast ? */
   Ltoggleoption = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "fastblank"));
   gtk_toggle_button_set_active(Ltoggleoption, conf_get_boolean("fastblank"));
@@ -1334,6 +1565,18 @@ GHashTable *create_dialog_proprietes (GtkWidget *Aparent)
   Ltoggleoption = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "eject"));
   gtk_toggle_button_set_active(Ltoggleoption, conf_get_boolean("eject"));
 
+  /* afficher le status bar ? */
+  Ltoggleoption = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "statusbar"));
+  gtk_toggle_button_set_active(Ltoggleoption, conf_get_boolean("statusbar"));
+  
+  /* combo taille des icones */
+  remplirecombo(GTK_COMBO_BOX(glade_to_hash(Lxml, Lhash, "iconsizelist")), "", 
+      Gtypeicosize, TRUE, conf_get_string("iconsize"));
+
+  /* sauver les donnees lorsque l'on quitte ? */
+  Ltoggleoption = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "saveconfig"));
+  gtk_toggle_button_set_active(Ltoggleoption, conf_get_boolean("saveconfig"));
+
   /* fonctions etendues ? */
 #if 0  
   Ltoggleoption = GTK_TOGGLE_BUTTON(glade_to_hash(Lxml, Lhash, "extended"));
@@ -1360,6 +1603,9 @@ GHashTable *create_dialog_proprietes (GtkWidget *Aparent)
   glade_to_hash_list(Lxml, Lhash, "mkisofs", "mkisofslbl", "mkisofspara", NULL);
   glade_to_hash_list(Lxml, Lhash, "readcd", "readcdlbl", "readcdpara", NULL);
   glade_to_hash_list(Lxml, Lhash, "sox", "soxlbl", "soxpara", NULL);
+  glade_to_hash_list(Lxml, Lhash, "growisofs", "growisofslbl", "growisofspara", NULL);
+  glade_to_hash_list(Lxml, Lhash, "dvd+rw-mediainfo", "dvd+rw-mediainfolbl", "dvd+rw-mediainfopara", NULL);
+  glade_to_hash_list(Lxml, Lhash, "dvd+rw-format", "dvd+rw-formatlbl", "dvd+rw-formatpara", NULL);
   glade_to_hash(Lxml, Lhash, "popupdevices");
 
   /** onglet "Lecteurs" **/
@@ -1473,10 +1719,12 @@ void show_erasecdrwwindow(GHashTable *Ahash)
   g_hash_table_insert(Lerasecdhash, "labelava", Llabel);
   g_hash_table_insert(Lerasecdhash, "progress", Lprogressbar);
   g_hash_table_insert(Lerasecdhash, "dstothercombo", g_hash_table_lookup(Ahash, "dstothercombo"));
+  g_hash_table_insert(Lerasecdhash, "usefastblank", g_hash_table_lookup(Ahash, "usefastblank"));
 
   /* bouton annuler */
   Lcancel = glade_xml_get_widget(Lxmlencours, "cancelbtn");
-  g_signal_connect(G_OBJECT(Lcancel), "clicked", G_CALLBACK(abort_encours), (GtkWidget *)Lerasecdhash);
+  g_signal_connect(G_OBJECT(Lcancel), "clicked", G_CALLBACK(abort_encours), Lerasecdhash);
+  g_signal_connect(G_OBJECT(Lwin), "delete-event", G_CALLBACK(delete_event_encours), Lerasecdhash);
 
   gtk_widget_show(Lwin);
   g_timeout_add(500, encours_callback, Lerasecdhash);
@@ -1540,7 +1788,8 @@ void show_fixcdwindow(GHashTable *Ahash)
 
   /* bouton annuler */
   Lcancel = glade_xml_get_widget(Lxmlencours, "cancelbtn");
-  g_signal_connect(G_OBJECT(Lcancel), "clicked", G_CALLBACK(abort_encours), (GtkWidget *)Lfixcdhash);
+  g_signal_connect(G_OBJECT(Lcancel), "clicked", G_CALLBACK(abort_encours), Lfixcdhash);
+  g_signal_connect(G_OBJECT(Lwin), "delete-event", G_CALLBACK(delete_event_encours), Lfixcdhash);
 
   gtk_widget_show(Lwin);
   g_timeout_add(500, encours_callback, Lfixcdhash);
@@ -1570,6 +1819,70 @@ void show_fixcdwindow(GHashTable *Ahash)
   if (Lerror) g_error_free(Lerror);
 }
 
+/* formater un dvd */
+void show_dvdformatwindow(GHashTable *Ahash, gchar *Atitle, Ttypeformatdvd Aoperation)
+{
+  GtkWidget *Lwindow1 = g_hash_table_lookup(Ahash, "window");
+  GladeXML *Lxmlencours = create_window_encours(Lwindow1);
+  gint Lcont = 2;
+  gint Lpid;
+  gboolean Loperationstatus = FALSE;
+  gboolean Labort = FALSE;
+  GtkWidget *Lprogressbar;
+  GtkLabel *Llabel;
+  GtkWidget *Lcancel;
+  GtkWidget *Lwin;
+  GHashTable *Lformatdvdhash = _hash();
+  GError *Lerror = NULL;
+  GtkWidget *Lstatusbox = NULL;
+
+  Lwin = glade_xml_get_widget(Lxmlencours, "window_inprogress"); 
+  Llabel = GTK_LABEL(glade_xml_get_widget(Lxmlencours, "labelava"));
+  gtk_label_set_text(Llabel, Atitle);
+
+  
+  Lprogressbar = glade_xml_get_widget(Lxmlencours, "progress");
+  g_hash_table_insert(Lformatdvdhash, "cont", &Lcont);
+  g_hash_table_insert(Lformatdvdhash, "pid", &Lpid);
+  g_hash_table_insert(Lformatdvdhash, "gabort", &Labort);
+  g_hash_table_insert(Lformatdvdhash, "gerror", &Lerror);
+  g_hash_table_insert(Lformatdvdhash, "operationstatus", &Loperationstatus);
+  g_hash_table_insert(Lformatdvdhash, "labelava", Llabel);
+  g_hash_table_insert(Lformatdvdhash, "progress", Lprogressbar);
+  g_hash_table_insert(Lformatdvdhash, "dstothercombo", g_hash_table_lookup(Ahash, "dstothercombo"));
+
+  /* bouton annuler */
+  Lcancel = glade_xml_get_widget(Lxmlencours, "cancelbtn");
+  g_signal_connect(G_OBJECT(Lcancel), "clicked", G_CALLBACK(abort_encours), Lformatdvdhash);
+  g_signal_connect(G_OBJECT(Lwin), "delete-event", G_CALLBACK(delete_event_encours), Lformatdvdhash);
+
+  gtk_widget_show(Lwin);
+//  g_timeout_add(500, encours_callback, Lformatdvdhash);
+  /* operation en elle meme */
+  perform_format_dvd(Lformatdvdhash, Aoperation, &Lerror);
+  
+  if (Labort) {
+    Lstatusbox = gtk_message_dialog_new(GTK_WINDOW(Lwin),
+                                     GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
+                                     _("Operation aborted by user !"));
+  } else if (Lerror) {
+    Lstatusbox = gtk_message_dialog_new(GTK_WINDOW(Lwin),
+                      GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
+                      Lerror->message);
+  } else {
+     Lstatusbox = gtk_message_dialog_new(GTK_WINDOW(Lwin),
+               GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
+               _("Operation successful"));
+  }
+  gtk_dialog_run(GTK_DIALOG(Lstatusbox));
+  gtk_widget_destroy(Lstatusbox);
+  
+  gtk_widget_destroy(Lwin);
+  g_hash_table_destroy(Lformatdvdhash);
+
+  if (Lerror) g_error_free(Lerror);
+}
+
 /*
  * vim:et:ts=8:sts=2:sw=2
  */
