@@ -73,7 +73,7 @@ gboolean graveman_init(gint Aargc, gchar *Aargv[]) {
       g_printf("  %s %s %s\n"
                "\t-v\t%s\n"
                "\t-V\t%s\n\n",
-              _("Usage:"), Aargv[0], _("[options]"), _("show version number."),
+               _("Usage:"), Aargv[0], _("[options]"), _("show version number."),
                _("show compilation informations."));
       return FALSE;
     }
@@ -100,29 +100,28 @@ gint main (gint Aargc, gchar *Aargv[])
 {
   GError *Lerror = NULL;
   GtkWidget *Lwindow1;
-  guint32 Laudiolen = 0, Ldatasize = 0;
+  guint32 Laudiolen = 0, Ldatasize = 0, Ldvdsize = 0;
   guint32 Laudiomaxlen = 4800;  /* par defaut, cd audio de 80 minutes */
   guint32 Ldatamaxsize = 700 * 1024 * 1024; /* par defaut, cd de donnee de 700 Mb */
-
-  if (!graveman_init(Aargc, Aargv)) return EXIT_SUCCESS;
+//  guint32 Ldvddatamaxsize = G_GINT64_CONSTANT(4700000000); /* pas default, dvd de donnee de 4.7 Gb */
 
 #ifdef ENABLE_NLS
   bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 #endif
-
   gtk_init (&Aargc, &Aargv);
 
+  if (!graveman_init(Aargc, Aargv)) return EXIT_SUCCESS;
+
   add_pixmap_directory (PACKAGE_DATA_DIR "/" PACKAGE );
-//  graveman_glade_init(PACKAGE_DATA_DIR "/" PACKAGE "/" PACKAGE ".glade");
 
   /* on regarde si il y a un fichier de configuration present, si non on en
    * genere un nouveau */
   config_init();
-  if (!is_config_valide()) {
+  if (!is_config_valid()) {
     GHashTable *Lhash = _hash();
-    manage_new_config(Lhash, SEARCH_LECTEUR + SEARCH_PROG + WRITE_CONFIG, &Lerror);
+    manage_config(Lhash, SEARCH_LECTEUR + SEARCH_PROG + WRITE_CONFIG, &Lerror);
     g_free(Lhash);
     welcome_to_graveman();
   } else {
@@ -131,7 +130,7 @@ gint main (gint Aargc, gchar *Aargv[])
 
   load_all_images();
   
-  Lwindow1 = manage_main_window (&Laudiolen, &Laudiomaxlen, &Ldatasize, &Ldatamaxsize);  
+  Lwindow1 = manage_main_window (&Laudiolen, &Laudiomaxlen, &Ldatasize, &Ldatamaxsize);
   gtk_main ();
   /* on libere avant de quitter */
   if (Lerror) g_error_free(Lerror);
