@@ -161,7 +161,7 @@ gint make_image(GHashTable *Ahash, GError **Aerror)
 
   Lbufvitesse = get_combo_value(Lvitesse);
   Lbuflect = get_combo_value(Llecteur);
-  Lcommandline = g_strdup_printf("%s dev=%s f=\"%s\" %s%s -clone -v",
+  Lcommandline = g_strdup_printf("%s dev=%s f=\"%s\" %s%s -v",
         conf_get_string("readcd"), Lbuflect, *Liso, *Lbufvitesse != '0' ? "speed=" : "", *Lbufvitesse != '0' ? Lbufvitesse : "");
   g_free(Lbuflect);
   g_free(Lbufvitesse);
