@@ -115,9 +115,11 @@ gboolean SoundToCdr(GHashTable *Ahash, gchar *AFichier, gchar *AVers, GError **A
   Lcomerrevent = g_io_add_watch (Lcomerr, (G_IO_IN | G_IO_HUP | G_IO_ERR | G_IO_PRI),
 					     sox_callback,
 					     Ahash);  
-  while (*Lcont > 1) {
+
+  while (*Lcont > 1 && *Labort == FALSE) {
     gtk_main_iteration(); 
   }
+
   g_source_remove(Lcomerrevent);
   g_source_remove(Lcomevent);
       
